@@ -106,12 +106,6 @@ ExampleAppWindow::ExampleAppWindow(BaseObjectType* cobject,
   m_binding_lines_visible = Glib::Binding::bind_property(m_lines->property_visible(),
     m_lines_label->property_visible());
 
-  // Display the application menu in the application, not in the desktop environment.
-  auto gtk_settings = Gtk::Settings::get_default();
-  if (gtk_settings)
-    gtk_settings->property_gtk_shell_shows_app_menu() = false;
-  set_show_menubar(true);
-
   // Set the window icon.
   Gtk::IconTheme::get_for_display(get_display())->add_resource_path("/org/gtkmm/exampleapp");
   set_icon_name("exampleapp");
@@ -135,14 +129,11 @@ void ExampleAppWindow::open_file_view(const Glib::RefPtr<Gio::File>& file)
   const Glib::ustring basename = file->get_basename();
 
   auto scrolled = Gtk::make_managed<Gtk::ScrolledWindow>();
-  scrolled->set_hexpand(true);
-  scrolled->set_vexpand(true);
-  scrolled->show();
+  scrolled->set_expand(true);
   auto view = Gtk::make_managed<Gtk::TextView>();
   view->set_editable(false);
   view->set_cursor_visible(false);
-  view->show();
-  scrolled->add(*view);
+  scrolled->set_child(*view);
   m_stack->add(*scrolled, basename, basename);
 
   auto buffer = view->get_buffer();
@@ -257,12 +248,8 @@ void ExampleAppWindow::update_words()
   }
 
   // Remove old children from the ListBox.
-  auto old_children = m_words->get_children();
-  for (auto child : old_children)
-  {
+  while (auto child = m_words->get_first_child())
     m_words->remove(*child);
-    delete child;
-  }
 
   // Add new child buttons, one per unique word.
   for (const auto& word : words)
@@ -270,8 +257,7 @@ void ExampleAppWindow::update_words()
     auto row = Gtk::make_managed<Gtk::Button>(word);
     row->signal_clicked().connect(sigc::bind(sigc::mem_fun(*this,
       &ExampleAppWindow::on_find_word), row));
-    row->show();
-    m_words->add(*row);
+    m_words->append(*row);
   }
 }
 
