@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2004 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,10 +32,12 @@ protected:
 
   //Child widgets:
   Gtk::Box m_VBox;
-  MyContainer m_MyContainer;
   Gtk::Button m_Button_One;
   Gtk::Label m_Label_Two;
-  Gtk::ButtonBox m_ButtonBox;
+  // A restriction with MyContainer is that it must be deleted before
+  // its children, meaning that it must be declared after its children.
+  MyContainer m_MyContainer;
+  Gtk::Box m_ButtonBox;
   Gtk::Button m_Button_Quit;
 };
 
