@@ -24,16 +24,16 @@ ExampleWindow::ExampleWindow()
 {
   set_title("Gtk::FontChooserDialog example");
 
-  add(m_ButtonBox);
+  set_child(m_ButtonBox);
 
-  m_ButtonBox.add(m_FontButton);
+  m_ButtonBox.append(m_FontButton);
   m_FontButton.set_expand(true);
   m_FontButton.set_use_font(true);
   m_FontButton.set_use_size(true);
   m_FontButton.signal_font_set().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_font_button_font_set) );
 
-  m_ButtonBox.add(m_Button_Dialog);
+  m_ButtonBox.append(m_Button_Dialog);
   m_Button_Dialog.set_expand(true);
   m_Button_Dialog.signal_clicked().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_button_dialog_clicked) );
@@ -51,19 +51,31 @@ void ExampleWindow::on_font_button_font_set()
 
 void ExampleWindow::on_button_dialog_clicked()
 {
-  Gtk::FontChooserDialog dialog("Please choose a font", *this);
+  if (!m_pDialog)
+  {
+    m_pDialog.reset(new Gtk::FontChooserDialog("Please choose a font", *this));
+    m_pDialog->set_modal(true);
+    m_pDialog->set_hide_on_close(true);
+    m_pDialog->signal_response().connect(
+      sigc::mem_fun(*this, &ExampleWindow::on_dialog_response));
+  }
 
   //Get the previously selected font name from the FontButton:
-  dialog.set_font(m_FontButton.get_font());
+  m_pDialog->set_font(m_FontButton.get_font());
 
-  int result = dialog.run();
+  m_pDialog->show();
+}
+
+void ExampleWindow::on_dialog_response(int response_id)
+{
+  m_pDialog->hide();
 
   //Handle the response:
-  switch(result)
+  switch (response_id)
   {
     case Gtk::ResponseType::OK:
     {
-      auto font_name = dialog.get_font();
+      auto font_name = m_pDialog->get_font();
       std::cout << "Font chosen: " << font_name << std::endl;
       m_FontButton.set_font(font_name);
       break;
@@ -75,7 +87,7 @@ void ExampleWindow::on_button_dialog_clicked()
     }
     default:
     {
-      std::cout << "Unexpected button clicked: " << result << std::endl;
+      std::cout << "Unexpected button clicked: " << response_id << std::endl;
       break;
     }
   }
