@@ -26,14 +26,14 @@ ExampleWindow::ExampleWindow()
 {
   set_title("Gtk::MessageDialog example");
 
-  add(m_ButtonBox);
+  set_child(m_ButtonBox);
 
-  m_ButtonBox.add(m_Button_Info);
+  m_ButtonBox.append(m_Button_Info);
   m_Button_Info.set_expand(true);
   m_Button_Info.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_info_clicked) );
 
-  m_ButtonBox.add(m_Button_Question);
+  m_ButtonBox.append(m_Button_Question);
   m_Button_Question.set_expand(true);
   m_Button_Question.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_question_clicked) );
@@ -45,25 +45,37 @@ ExampleWindow::~ExampleWindow()
 
 void ExampleWindow::on_button_info_clicked()
 {
-  Gtk::MessageDialog dialog(*this, "This is an INFO MessageDialog");
-  dialog.set_secondary_text(
+  m_pDialog.reset(new Gtk::MessageDialog(*this, "This is an INFO MessageDialog"));
+  m_pDialog->set_secondary_text(
           "And this is the secondary text that explains things.");
+  m_pDialog->set_modal(true);
+  m_pDialog->set_hide_on_close(true);
+  m_pDialog->signal_response().connect(
+    sigc::hide(sigc::mem_fun(*m_pDialog, &Gtk::Widget::hide)));
 
-  dialog.run();
+  m_pDialog->show();
 }
 
 void ExampleWindow::on_button_question_clicked()
 {
-  Gtk::MessageDialog dialog(*this, "This is a QUESTION MessageDialog",
+  m_pDialog.reset(new Gtk::MessageDialog(*this, "This is a QUESTION MessageDialog",
           false /* use_markup */, Gtk::MessageType::QUESTION,
-          Gtk::ButtonsType::OK_CANCEL);
-  dialog.set_secondary_text(
+          Gtk::ButtonsType::OK_CANCEL, true /* modal */));
+  m_pDialog->set_secondary_text(
           "And this is the secondary text that explains things.");
+  m_pDialog->set_hide_on_close(true);
+  m_pDialog->signal_response().connect(
+    sigc::mem_fun(*this, &ExampleWindow::on_question_dialog_response));
 
-  int result = dialog.run();
+  m_pDialog->show();
+}
+
+void ExampleWindow::on_question_dialog_response(int response_id)
+{
+  m_pDialog->hide();
 
   //Handle the response:
-  switch(result)
+  switch (response_id)
   {
     case Gtk::ResponseType::OK:
     {
