@@ -36,11 +36,11 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   set_title(app_title);
   set_default_size(400, 300);
 
-  add(m_VBox);
+  set_child(m_VBox);
 
   build_main_menu(app);
 
-  m_VBox.add(m_Grid);
+  m_VBox.append(m_Grid);
 
   //Arrange the widgets inside the grid:
   m_Grid.set_expand(true);
@@ -53,7 +53,7 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   m_Grid.attach(m_SurnameEntry, 1, 1);
 
   //Add the TextView, inside a ScrolledWindow:
-  m_ScrolledWindow.add(m_TextView);
+  m_ScrolledWindow.set_child(m_TextView);
 
   //Only show the scrollbars when they are necessary:
   m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
@@ -66,7 +66,7 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   m_TextView.set_buffer(m_refTextBuffer);
 
   m_Statusbar.set_expand(true);
-  m_VBox.add(m_Statusbar);
+  m_VBox.append(m_Statusbar);
 }
 
 ExampleWindow::~ExampleWindow()
@@ -155,7 +155,6 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
   Glib::ustring ui_toolbar_info =
     "<!-- Generated with glade 3.18.3 and then changed manually -->"
     "<interface>"
-      "<requires lib='gtk' version='3.98'/>"
       "<object class='GtkBox' id='toolbar'>"
         "<property name='can_focus'>False</property>"
         "<property name='spacing'>3</property>"
@@ -165,7 +164,8 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
             "<property name='tooltip_text' translatable='yes'>New</property>"
             "<property name='action_name'>example.new</property>"
             "<property name='icon_name'>document-new</property>"
-            "<property name='expand'>False</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
         "<child>"
@@ -174,13 +174,15 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
             "<property name='tooltip_text' translatable='yes'>Print</property>"
             "<property name='action_name'>example.print</property>"
             "<property name='icon_name'>document-print</property>"
-            "<property name='expand'>False</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
         "<child>"
           "<object class='GtkSeparator' id='separator1'>"
             "<property name='can_focus'>False</property>"
-            "<property name='expand'>False</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
         "<child>"
@@ -189,7 +191,8 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
             "<property name='tooltip_text' translatable='yes'>Quit</property>"
             "<property name='action_name'>example.quit</property>"
             "<property name='icon_name'>application-exit</property>"
-            "<property name='expand'>False</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
       "</object>"
@@ -214,7 +217,7 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
     auto pMenuBar = Gtk::make_managed<Gtk::PopoverMenuBar>(gmenu);
 
     // Add the PopoverMenuBar to the window:
-    m_VBox.add(*pMenuBar);
+    m_VBox.append(*pMenuBar);
   }
 
   // Get the toolbar and add it to a container widget:
@@ -222,7 +225,7 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
   if (!toolbar)
     g_warning("toolbar not found");
   else
-    m_VBox.add(*toolbar);
+    m_VBox.append(*toolbar);
 }
 
 void ExampleWindow::on_printoperation_status_changed()
@@ -248,9 +251,16 @@ void ExampleWindow::on_printoperation_done(Gtk::PrintOperation::Result result)
 
   if (result == Gtk::PrintOperation::Result::ERROR)
   {
-    Gtk::MessageDialog err_dialog(*this, "Error printing form", false,
-            Gtk::MessageType::ERROR, Gtk::ButtonsType::OK, true);
-    err_dialog.run();
+    if (!m_pDialog)
+    {
+      m_pDialog.reset(new Gtk::MessageDialog(*this, "Error printing form",
+        false /* use_markup */, Gtk::MessageType::ERROR, Gtk::ButtonsType::OK,
+        true /* modal */));
+      m_pDialog->set_hide_on_close(true);
+      m_pDialog->signal_response().connect(
+        sigc::hide(sigc::mem_fun(*m_pDialog, &Gtk::Widget::hide)));
+    }
+    m_pDialog->show();
   }
   else if (result == Gtk::PrintOperation::Result::APPLY)
   {
