@@ -76,7 +76,7 @@ AppWindow::AppWindow()
   grid->set_row_spacing(5);
   grid->set_column_spacing(5);
 
-  add (*grid);
+  set_child (*grid);
 }
 
 AppWindow::~AppWindow()
@@ -85,9 +85,8 @@ AppWindow::~AppWindow()
 int main (int argc, char *argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
-  AppWindow arrows;
 
-  return app->run(arrows, argc, argv);
+  return app->make_window_and_run<AppWindow>(argc, argv);
 }
 
 /* example-end */
