@@ -52,7 +52,7 @@ AppWindow::AppWindow()
   list_store_   (Gtk::ListStore::create(list_columns_)),
   tree_view_    (list_store_)
 {
-  add(tree_view_);
+  set_child(tree_view_);
 
   tree_view_.append_column("Text 1", list_columns_.text1);
 
@@ -108,9 +108,6 @@ int main(int argc, char** argv)
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
 
-  AppWindow window;
-  app->run(window, argc, argv);
-
-  return 0;
+  return app->make_window_and_run<AppWindow>(argc, argv);
 }
 
